==> s-render-0.5.92.tgz: package/es/FormRender/widgets/container/FileComponent/index.js <==
import "antd/es/col/style";
import _Col from "antd/es/col";
import "antd/es/card/style";
import _Card from "antd/es/card";
import "antd/es/upload/style";
import _Upload from "antd/es/upload";
import _InboxOutlined from "@ant-design/icons/lib/icons/InboxOutlined";
import "antd/es/space/style";
import _Space from "antd/es/space";
import _DeleteOutlined from "@ant-design/icons/lib/icons/DeleteOutlined";
import _EyeOutlined from "@ant-design/icons/lib/icons/EyeOutlined";
import "antd/es/image/style";
import _Image from "antd/es/image";
import "antd/es/form/style";
import _Form from "antd/es/form";
var _excluded = ["thumbUrl"];
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { useContext, useState } from 'react';
import { useStore } from 'zustand';
import { FormRenderContext } from "../../../models/context";
import "./index.less";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var isImageFileType = function isImageFileType(type) {
  return type.indexOf('image/') === 0;
};
var FileComponent = function FileComponent(props) {
  var _useStore;
  var store = useContext(FormRenderContext);
  var _ref = (_useStore = useStore(store, function (state) {
      return state.context;
    })) !== null && _useStore !== void 0 ? _useStore : {},
    uploadConfig = _ref.uploadConfig,
    readOnly = _ref.readOnly;
  var schema = props.schema,
    path = props.path;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    previewVisible = _useState2[0],
    setPreviewVisible = _useState2[1];
  var _useState3 = useState(0),
    _useState4 = _slicedToArray(_useState3, 2),
    previewIndex = _useState4[0],
    setPreviewIndex = _useState4[1];
  var form = _Form.useFormInstance();
  var _fileList = _Form.useWatch(path, form);
  if (!uploadConfig) {
    console.error('请配置uploadConfig');
    return null;
  }
  var imageList = _fileList === null || _fileList === void 0 ? void 0 : _fileList.filter(function (item) {
    return isImageFileType(item === null || item === void 0 ? void 0 : item.type) && (item === null || item === void 0 ? void 0 : item.status) === 'done' && (item === null || item === void 0 ? void 0 : item.response);
  });
  var normFile = function normFile(e) {
    if (Array.isArray(e)) {
      return e;
    }
    return e === null || e === void 0 ? void 0 : e.fileList;
  };
  var customRequest = function customRequest(info) {
    var onProgress = info.onProgress,
      onSuccess = info.onSuccess,
      file = info.file,
      onError = info.onError;
    uploadConfig === null || uploadConfig === void 0 ? void 0 : uploadConfig.uploadRequest(file, onProgress).then(function (res) {
      var thumbUrl = file.thumbUrl,
        other = _objectWithoutProperties(file, _excluded);
      onSuccess(res, other);
    }).catch(function () {
      onError();
    });
  };
  var itemRender = function itemRender(originNode, file, fileList, actions) {
    if (file.type && isImageFileType(file.type)) {
      var _file$thumbUrl, _uploadConfig$downloa;
      return /*#__PURE__*/_jsxs("div", {
        className: "srender-image-wrapper",
        children: [/*#__PURE__*/_jsx(_Image, {
          src: (_file$thumbUrl = file === null || file === void 0 ? void 0 : file.thumbUrl) !== null && _file$thumbUrl !== void 0 ? _file$thumbUrl : uploadConfig === null || uploadConfig === void 0 ? void 0 : (_uploadConfig$downloa = uploadConfig.downloadImageUrl) === null || _uploadConfig$downloa === void 0 ? void 0 : _uploadConfig$downloa.call(uploadConfig, file === null || file === void 0 ? void 0 : file.response),
          preview: false
        }), /*#__PURE__*/_jsx("div", {
          className: "srender-image-actions",
          children: /*#__PURE__*/_jsxs(_Space, {
            children: [/*#__PURE__*/_jsx(_EyeOutlined, {
              onClick: actions.preview
            }), !readOnly && /*#__PURE__*/_jsx(_DeleteOutlined, {
              onClick: actions.remove
            })]
          })
        })]
      });
    }
    return originNode;
  };
  var onPreview = function onPreview(file) {
    setPreviewVisible(true);
    var index = imageList === null || imageList === void 0 ? void 0 : imageList.findIndex(function (item) {
      return (item === null || item === void 0 ? void 0 : item.uid) === (file === null || file === void 0 ? void 0 : file.uid);
    });
    setPreviewIndex(index);
  };
  return /*#__PURE__*/_jsxs(_Col, {
    span: 24,
    children: [/*#__PURE__*/_jsx(_Card, {
      size: "small",
      type: "inner",
      title: /*#__PURE__*/_jsx("div", {
        className: (schema === null || schema === void 0 ? void 0 : schema.required) && 'srender-file-component-required' || '',
        children: schema === null || schema === void 0 ? void 0 : schema.title
      }),
      className: "srender-file-component",
      children: /*#__PURE__*/_jsx(_Form.Item, {
        name: path,
        rules: [{
          required: schema === null || schema === void 0 ? void 0 : schema.required,
          message: "\u8BF7\u4E0A\u4F20".concat(schema === null || schema === void 0 ? void 0 : schema.title)
        }],
        valuePropName: "fileList",
        getValueFromEvent: normFile,
        children: /*#__PURE__*/_jsxs(_Upload.Dragger, {
          listType: "picture-card",
          customRequest: customRequest,
          onDownload: uploadConfig === null || uploadConfig === void 0 ? void 0 : uploadConfig.downloadRequest,
          onPreview: onPreview,
          showUploadList: {
            showPreviewIcon: false,
            showDownloadIcon: true,
            showRemoveIcon: !readOnly
          },
          itemRender: itemRender,
          disabled: readOnly,
          children: [/*#__PURE__*/_jsx("p", {
            className: "ant-upload-drag-icon",
            children: /*#__PURE__*/_jsx(_InboxOutlined, {})
          }), /*#__PURE__*/_jsx("p", {
            className: "ant-upload-text",
            children: "\u5355\u51FB\u6216\u62D6\u52A8\u6587\u4EF6\u5230\u6B64\u533A\u57DF\u8FDB\u884C\u4E0A\u4F20"
          })]
        })
      })
    }), /*#__PURE__*/_jsx(_Image.PreviewGroup, {
      preview: {
        visible: previewVisible,
        current: previewIndex,
        onVisibleChange: function onVisibleChange(visible) {
          setPreviewVisible(visible);
          setPreviewIndex(0);
        },
        onChange: function onChange(index) {
          setPreviewIndex(index);
        }
      },
      items: imageList === null || imageList === void 0 ? void 0 : imageList.map(function (item) {
        var _item$thumbUrl, _uploadConfig$downloa2;
        return (_item$thumbUrl = item === null || item === void 0 ? void 0 : item.thumbUrl) !== null && _item$thumbUrl !== void 0 ? _item$thumbUrl : uploadConfig === null || uploadConfig === void 0 ? void 0 : (_uploadConfig$downloa2 = uploadConfig.downloadImageUrl) === null || _uploadConfig$downloa2 === void 0 ? void 0 : _uploadConfig$downloa2.call(uploadConfig, item === null || item === void 0 ? void 0 : item.response);
      })
    })]
  });
};
export default FileComponent;

==> s-render-0.5.93.tgz: package/es/FormRender/widgets/container/FileComponent/index.js <==
import "antd/es/col/style";
import _Col from "antd/es/col";
import "antd/es/card/style";
import _Card from "antd/es/card";
import "antd/es/upload/style";
import _Upload from "antd/es/upload";
import _InboxOutlined from "@ant-design/icons/lib/icons/InboxOutlined";
import _DownloadOutlined from "@ant-design/icons/lib/icons/DownloadOutlined";
import _FilePdfOutlined from "@ant-design/icons/lib/icons/FilePdfOutlined";
import "antd/es/space/style";
import _Space from "antd/es/space";
import _DeleteOutlined from "@ant-design/icons/lib/icons/DeleteOutlined";
import _EyeOutlined from "@ant-design/icons/lib/icons/EyeOutlined";
import "antd/es/image/style";
import _Image from "antd/es/image";
import "antd/es/form/style";
import _Form from "antd/es/form";
var _excluded = ["thumbUrl"];
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { useContext, useState } from 'react';
import { useStore } from 'zustand';
import { FormRenderContext } from "../../../models/context";
import "./index.less";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var isImageFileType = function isImageFileType(type) {
  return type.indexOf('image/') === 0;
};
var FileComponent = function FileComponent(props) {
  var _useStore;
  var store = useContext(FormRenderContext);
  var _ref = (_useStore = useStore(store, function (state) {
      return state.context;
    })) !== null && _useStore !== void 0 ? _useStore : {},
    uploadConfig = _ref.uploadConfig,
    readOnly = _ref.readOnly;
  var schema = props.schema,
    path = props.path;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    previewVisible = _useState2[0],
    setPreviewVisible = _useState2[1];
  var _useState3 = useState(0),
    _useState4 = _slicedToArray(_useState3, 2),
    previewIndex = _useState4[0],
    setPreviewIndex = _useState4[1];
  var form = _Form.useFormInstance();
  var _fileList = _Form.useWatch(path, form);
  if (!uploadConfig) {
    console.error('请配置uploadConfig');
    return null;
  }
  var imageList = _fileList === null || _fileList === void 0 ? void 0 : _fileList.filter(function (item) {
    return isImageFileType(item === null || item === void 0 ? void 0 : item.type) && (item === null || item === void 0 ? void 0 : item.status) === 'done' && (item === null || item === void 0 ? void 0 : item.response);
  });
  var normFile = function normFile(e) {
    if (Array.isArray(e)) {
      return e;
    }
    return e === null || e === void 0 ? void 0 : e.fileList;
  };
  var customRequest = function customRequest(info) {
    var onProgress = info.onProgress,
      onSuccess = info.onSuccess,
      file = info.file,
      onError = info.onError;
    uploadConfig === null || uploadConfig === void 0 ? void 0 : uploadConfig.uploadRequest(file, onProgress).then(function (res) {
      var thumbUrl = file.thumbUrl,
        other = _objectWithoutProperties(file, _excluded);
      onSuccess(res, other);
    }).catch(function () {
      onError();
    });
  };
  var itemRender = function itemRender(originNode, file, fileList, actions) {
    if (file.type && isImageFileType(file.type)) {
      var _file$thumbUrl, _uploadConfig$downloa;
      return /*#__PURE__*/_jsxs("div", {
        className: "srender-image-wrapper",
        children: [/*#__PURE__*/_jsx(_Image, {
          src: (_file$thumbUrl = file === null || file === void 0 ? void 0 : file.thumbUrl) !== null && _file$thumbUrl !== void 0 ? _file$thumbUrl : uploadConfig === null || uploadConfig === void 0 ? void 0 : (_uploadConfig$downloa = uploadConfig.downloadImageUrl) === null || _uploadConfig$downloa === void 0 ? void 0 : _uploadConfig$downloa.call(uploadConfig, file === null || file === void 0 ? void 0 : file.response),
          preview: false
        }), /*#__PURE__*/_jsx("div", {
          className: "srender-image-actions",
          children: /*#__PURE__*/_jsxs(_Space, {
            children: [/*#__PURE__*/_jsx(_EyeOutlined, {
              onClick: actions.preview
            }), !readOnly && /*#__PURE__*/_jsx(_DeleteOutlined, {
              onClick: actions.remove
            })]
          })
        })]
      });
    }
    return /*#__PURE__*/_jsxs("div", {
      className: "srender-image-wrapper srender-file-component-not-image",
      children: [/*#__PURE__*/_jsx(_FilePdfOutlined, {
        className: "srender-file-component-icon"
      }), /*#__PURE__*/_jsx("div", {
        className: "srender-file-component-not-image-name",
        children: file.name
      }), /*#__PURE__*/_jsx("div", {
        className: "srender-image-actions",
        children: /*#__PURE__*/_jsxs(_Space, {
          children: [/*#__PURE__*/_jsx(_DownloadOutlined, {
            onClick: actions.download
          }), !readOnly && /*#__PURE__*/_jsx(_DeleteOutlined, {
            onClick: actions.remove
          })]
        })
      })]
    });
  };
  var onPreview = function onPreview(file) {
    setPreviewVisible(true);
    var index = imageList === null || imageList === void 0 ? void 0 : imageList.findIndex(function (item) {
      return (item === null || item === void 0 ? void 0 : item.uid) === (file === null || file === void 0 ? void 0 : file.uid);
    });
    setPreviewIndex(index);
  };
  return /*#__PURE__*/_jsxs(_Col, {
    span: 24,
    children: [/*#__PURE__*/_jsx(_Card, {
      size: "small",
      type: "inner",
      title: /*#__PURE__*/_jsx("div", {
        className: (schema === null || schema === void 0 ? void 0 : schema.required) && 'srender-file-component-required' || '',
        children: schema === null || schema === void 0 ? void 0 : schema.title
      }),
      className: "srender-file-component",
      children: /*#__PURE__*/_jsx(_Form.Item, {
        name: path,
        rules: [{
          required: schema === null || schema === void 0 ? void 0 : schema.required,
          message: "\u8BF7\u4E0A\u4F20".concat(schema === null || schema === void 0 ? void 0 : schema.title)
        }],
        valuePropName: "fileList",
        getValueFromEvent: normFile,
        children: /*#__PURE__*/_jsxs(_Upload.Dragger, {
          listType: "picture-card",
          customRequest: customRequest,
          onDownload: uploadConfig === null || uploadConfig === void 0 ? void 0 : uploadConfig.downloadRequest,
          onPreview: onPreview,
          showUploadList: {
            showPreviewIcon: false,
            showDownloadIcon: true
          },
          itemRender: itemRender,
          disabled: readOnly,
          children: [/*#__PURE__*/_jsx("p", {
            className: "ant-upload-drag-icon",
            children: /*#__PURE__*/_jsx(_InboxOutlined, {})
          }), /*#__PURE__*/_jsx("p", {
            className: "ant-upload-text",
            children: "\u5355\u51FB\u6216\u62D6\u52A8\u6587\u4EF6\u5230\u6B64\u533A\u57DF\u8FDB\u884C\u4E0A\u4F20"
          })]
        })
      })
    }), /*#__PURE__*/_jsx(_Image.PreviewGroup, {
      preview: {
        visible: previewVisible,
        current: previewIndex,
        onVisibleChange: function onVisibleChange(visible) {
          setPreviewVisible(visible);
          setPreviewIndex(0);
        },
        onChange: function onChange(index) {
          setPreviewIndex(index);
        }
      },
      items: imageList === null || imageList === void 0 ? void 0 : imageList.map(function (item) {
        var _item$thumbUrl, _uploadConfig$downloa2;
        return (_item$thumbUrl = item === null || item === void 0 ? void 0 : item.thumbUrl) !== null && _item$thumbUrl !== void 0 ? _item$thumbUrl : uploadConfig === null || uploadConfig === void 0 ? void 0 : (_uploadConfig$downloa2 = uploadConfig.downloadImageUrl) === null || _uploadConfig$downloa2 === void 0 ? void 0 : _uploadConfig$downloa2.call(uploadConfig, item === null || item === void 0 ? void 0 : item.response);
      })
    })]
  });
};
export default FileComponent;
